==> zhmcclient_0.22.0.orig.tar.gz: zhmcclient-0.22.0/zhmcclient/__init__.py <==
# Copyright 2016-2017 IBM Corp. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
zhmcclient - A pure Python client library for the IBM Z HMC Web Services
API.

For documentation, see TODO: Add link to RTD once available.
"""

from __future__ import absolute_import

from ._version import *       # noqa: F401
from ._constants import *     # noqa: F401
from ._exceptions import *    # noqa: F401
from ._manager import *       # noqa: F401
from ._resource import *      # noqa: F401
from ._logging import *       # noqa: F401
from ._session import *       # noqa: F401
from ._timestats import *     # noqa: F401
from ._client import *        # noqa: F401
from ._cpc import *           # noqa: F401
from ._lpar import *          # noqa: F401
from ._partition import *     # noqa: F401
from ._activation_profile import *     # noqa: F401
from ._adapter import *       # noqa: F401
from ._nic import *           # noqa: F401
from ._hba import *           # noqa: F401
from ._virtual_function import *       # noqa: F401
from ._virtual_switch import *         # noqa: F401
from ._port import *          # noqa: F401
from ._notification import *  # noqa: F401
from ._metrics import *       # noqa: F401
from ._utils import *         # noqa: F401
from ._console import *       # noqa: F401
from ._user import *          # noqa: F401
from ._user_role import *     # noqa: F401
from ._user_pattern import *  # noqa: F401
from ._password_rule import *          # noqa: F401
from ._task import *          # noqa: F401
from ._ldap_server_definition import *         # noqa: F401
from ._unmanaged_cpc import *          # noqa: F401
from ._storage_group import *          # noqa: F401
from ._storage_volume import *         # noqa: F401
from ._virtual_storage_resource import *        # noqa: F401

==> zhmcclient-0.26.1.tar.gz: zhmcclient-0.26.1/zhmcclient/__init__.py <==
# Copyright 2016-2017 IBM Corp. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
zhmcclient - A pure Python client library for the IBM Z HMC Web Services
API.

For documentation, see TODO: Add link to RTD once available.
"""

from __future__ import absolute_import

from ._version import *       # noqa: F401
from ._constants import *     # noqa: F401
from ._exceptions import *    # noqa: F401
from ._manager import *       # noqa: F401
from ._resource import *      # noqa: F401
from ._logging import *       # noqa: F401
from ._session import *       # noqa: F401
from ._timestats import *     # noqa: F401
from ._client import *        # noqa: F401
from ._cpc import *           # noqa: F401
from ._lpar import *          # noqa: F401
from ._partition import *     # noqa: F401
from ._activation_profile import *     # noqa: F401
from ._adapter import *       # noqa: F401
from ._nic import *           # noqa: F401
from ._hba import *           # noqa: F401
from ._virtual_function import *       # noqa: F401
from ._virtual_switch import *         # noqa: F401
from ._port import *          # noqa: F401
from ._notification import *  # noqa: F401
from ._metrics import *       # noqa: F401
from ._utils import *         # noqa: F401
from ._console import *       # noqa: F401
from ._user import *          # noqa: F401
from ._user_role import *     # noqa: F401
from ._user_pattern import *  # noqa: F401
from ._password_rule import *          # noqa: F401
from ._task import *          # noqa: F401
from ._ldap_server_definition import *         # noqa: F401
from ._unmanaged_cpc import *          # noqa: F401
from ._storage_group import *          # noqa: F401
from ._storage_volume import *         # noqa: F401
from ._virtual_storage_resource import *        # noqa: F401
from ._storage_group_template import *          # noqa: F401
from ._storage_volume_template import *         # noqa: F401
